Learn R Programming

AIUQ (version 0.5.3)

AIUQ-package: AIUQ: Ab Initio Uncertainty Quantification

Description

Uncertainty quantification and inverse estimation by probabilistic generative models from the beginning of the data analysis. An example is a Fourier basis method for inverse estimation in scattering analysis of microscopy videos. It does not require specifying a certain range of Fourier bases and it substantially reduces computational cost via the generalized Schur algorithm. See the reference: Mengyang Gu, Yue He, Xubo Liu and Yimin Luo (2023), tools:::Rd_expr_doi("10.48550/arXiv.2309.02468").

Arguments

Author

Maintainer: Mengyang Gu mengyang@pstat.ucsb.edu

Authors:

  • Yue He

  • Xubo Liu