Learn R Programming

AIUQ (version 0.5.3)

anisotropic_bm_particle_intensity: Simulate 2D particle trajectory follows anisotropic Brownian Motion

Description

Simulate 2D particle trajectory follows anisotropic Brownian Motion (BM) for M particles, with different step sizes in x, y-directions.

Usage

anisotropic_bm_particle_intensity(pos0, M, len_t, sigma)

Value

Position matrix with dimension M\(\times\)len_t

by 2 for particle trajectory. The first M rows being the initial position pos0.

Arguments

pos0

initial position for M particles, matrix with dimension M by 2

M

number of particles

len_t

number of time steps

sigma

distance moved per time step in x,y-directions, a vector of length 2

Author

tools:::Rd_package_author("AIUQ")

Examples

Run this code
library(AIUQ)
M = 10
len_t = 50
sigma = c(0.5,0.1)
pos0 = matrix(100/8+0.75*100*runif(M*2),nrow=M,ncol=2)
pos = anisotropic_bm_particle_intensity(pos0=pos0,M=M,len_t=len_t,sigma=sigma)

Run the code above in your browser using DataLab