cart2polar: Transform Cartesian coordinates to polar coordinates
Description
Transform ordered pair (x,y), where x and y denotes the
directed distance between the point and each of two
perpendicular lines, the x-axis and the y-axis, to polar
coordinate. Input x and y must have the same length.
Usage
cart2polar(x, y)
Value
A data frame with 2 variables, where r is the
directed distance from a point designed as the pole, and
theta represents the angle, in radians, between the pole and the point.