Learn R Programming

AIUQ (version 0.5.3)

fbm_particle_intensity: Simulate 2D particle trajectory follows fBM

Description

Simulate 2D particle trajectory follows fraction Brownian Motion(fBM) for M particles.

Usage

fbm_particle_intensity(pos0, M, len_t, sigma, H)

Value

Position matrix with dimension M\(\times\)len_t

by 2 for particle trajectory. The first M rows being the initial position pos0.

Arguments

pos0

initial position for M particles, matrix with dimension M by 2

M

number of particles

len_t

number of time steps

sigma

distance moved per time step

H

Hurst parameter, value between 0 and 1

Author

tools:::Rd_package_author("AIUQ")

Examples

Run this code
library(AIUQ)
M = 10
len_t = 50
sigma = 2
H = 0.3
pos0 = matrix(100/8+0.75*100*runif(M*2),nrow=M,ncol=2)
pos = fbm_particle_intensity(pos0=pos0,M=M,len_t=len_t,sigma=sigma,H=H)

Run the code above in your browser using DataLab