Learn R Programming

AIUQ (version 0.5.3)

get_est_parameters_MSD_SAM_interval: Construct 95% confidence interval

Description

This function construct the lower and upper bound for 95% confidence interval of estimated parameters and mean squared displacement(MSD) for a given model. See 'References'.

Usage

get_est_parameters_MSD_SAM_interval(
  param_uq_range,
  model_name,
  d_input,
  msd_fn = NA
)

Value

A list of lower and upper bound for 95% confidence interval of estimated parameters and MSD for a given model.

Arguments

param_uq_range

lower and upper bound for natural logorithm of parameters in the fitted model using AIUQ method in SAM class

model_name

model for constructing MSD, options from ('BM','OU', 'FBM','OU+FBM', 'user_defined')

d_input

sequence of lag times

msd_fn

user defined mean squared displacement structure (MSD), a function of param parameters and d_input lag times

Author

tools:::Rd_package_author("AIUQ")

References

Gu, M., He, Y., Liu, X., & Luo, Y. (2023). Ab initio uncertainty quantification in scattering analysis of microscopy. arXiv preprint arXiv:2309.02468.

Gu, M., Luo, Y., He, Y., Helgeson, M. E., & Valentine, M. T. (2021). Uncertainty quantification and estimation in differential dynamic microscopy. Physical Review E, 104(3), 034610.

Cerbino, R., & Trappe, V. (2008). Differential dynamic microscopy: probing wave vector dependent dynamics with a microscope. Physical review letters, 100(18), 188102.