Construct parameter transformation for parameters to be optimized over in AIUQ
method of SAM class. See 'References'.
get_grad_trans(theta, d_input, model_name)A vector of transformed parameters to be optimized over in AIUQ
method of SAM class.
parameters to be optimized over
sequence of lag times
model name for the fitted model, options from ('BM','OU', 'FBM',OU+FBM','user_defined')
tools:::Rd_package_author("AIUQ")
Gu, M., He, Y., Liu, X., & Luo, Y. (2023). Ab initio uncertainty quantification in scattering analysis of microscopy. arXiv preprint arXiv:2309.02468.
Gu, M., Luo, Y., He, Y., Helgeson, M. E., & Valentine, M. T. (2021). Uncertainty quantification and estimation in differential dynamic microscopy. Physical Review E, 104(3), 034610.