This function computes the natural logarithm of the likelihood of the latent factor model for selected range of wave vectors. See 'References'.
log_lik(
param,
I_q_cur,
B_cur,
index_q,
I_o_q_2_ori,
d_input,
q_ori_ring_loc_unique_index,
sz,
len_t,
q,
model_name,
A_neg,
msd_fn = NA,
msd_grad_fn = NA
)The numerical value of natural logarithm of the likelihood.
a vector of natural logarithm of parameters
Fourier transformed intensity profile
current value of B. This parameter is determined by the noise in the system. See 'References'.
selected index of wave number
absolute square of Fourier transformed intensity profile, ensemble over time
sequence of lag times
index for wave vector that give unique frequency
frame size of the intensity profile
number of time steps
wave vector in unit of um^-1
model for constructing MSD, options from ('BM','OU', 'FBM','OU+FBM', 'user_defined')
user defined mean squared displacement structure (MSD), a
function of param parameters and d_input lag times
user defined MSD gradient structure, a function of
param and d_input
tools:::Rd_package_author("AIUQ")
Gu, M., He, Y., Liu, X., & Luo, Y. (2023). Ab initio uncertainty quantification in scattering analysis of microscopy. arXiv preprint arXiv:2309.02468.
Gu, M., Luo, Y., He, Y., Helgeson, M. E., & Valentine, M. T. (2021). Uncertainty quantification and estimation in differential dynamic microscopy. Physical Review E, 104(3), 034610.
Cerbino, R., & Trappe, V. (2008). Differential dynamic microscopy: probing wave vector dependent dynamics with a microscope. Physical review letters, 100(18), 188102.