Learn R Programming

AIUQ (version 0.5.3)

modeled_dqt: Compute modeled dynamic image structure function

Description

Compute modeled dynamic image structure function (Dqt) using object of SAM class.

Usage

modeled_dqt(object, index_q = NA, uncertainty = FALSE)

Value

A matrix of modeled dynamic image structure function with dimension len_q by len_t-1.

Arguments

object

an S4 object of class SAM

index_q

wavevector range used for computing Dqt

uncertainty

logic evalution

Author

tools:::Rd_package_author("AIUQ")

References

Gu, M., He, Y., Liu, X., & Luo, Y. (2023). Ab initio uncertainty quantification in scattering analysis of microscopy. arXiv preprint arXiv:2309.02468.

Gu, M., Luo, Y., He, Y., Helgeson, M. E., & Valentine, M. T. (2021). Uncertainty quantification and estimation in differential dynamic microscopy. Physical Review E, 104(3), 034610.

Cerbino, R., & Trappe, V. (2008). Differential dynamic microscopy: probing wave vector dependent dynamics with a microscope. Physical review letters, 100(18), 188102.

Examples

Run this code
library(AIUQ)
sim_bm = simulation(len_t=100,sz=100,sigma_bm=0.5)
show(sim_bm)
sam = SAM(sim_object = sim_bm)
show(sam)
modeled_Dqt = modeled_dqt(object=sam)

Run the code above in your browser using DataLab