Learn R Programming

AIUQ (version 0.5.3)

show.aniso_simulation: Show anisotropic simulation object

Description

Function to print the aniso_simulation class object after the aniso_simulation model has been constructed.

Usage

show.aniso_simulation(object)

Value

Show a list of important parameters in class aniso_simulation.

Arguments

object

an S4 object of class aniso_simulation

Author

tools:::Rd_package_author("AIUQ")

References

Gu, M., He, Y., Liu, X., & Luo, Y. (2023). Ab initio uncertainty quantification in scattering analysis of microscopy. arXiv preprint arXiv:2309.02468.

Gu, M., Luo, Y., He, Y., Helgeson, M. E., & Valentine, M. T. (2021). Uncertainty quantification and estimation in differential dynamic microscopy. Physical Review E, 104(3), 034610.

Examples

Run this code
library(AIUQ)

# Simulate simple diffusion for 100 images with 100 by 100 pixels
aniso_sim_bm = aniso_simulation(sz=100,len_t=100,sigma_bm=c(0.5,0.1))
show(aniso_sim_bm)

Run the code above in your browser using DataLab