Construct intensity profile with structure 'T_SS_mat' for a given particle trajectory, background intensity profile, and user defined radius of particle.
fill_intensity(len_t, M, I, pos, Ic, sz, sigma_p)Intensity profile matrix with structure 'T_SS_mat' (matrix with
dimension len_t by sz\(\times\)sz).
number of time steps
number of particles
background intensity profile. See 'Details'.
position matrix for particle trajectory
vector of maximum intensity of each particle
frame size of simulated square image
radius of the spherical particle (3sigma_p)
tools:::Rd_package_author("AIUQ")
Input I should has structure 'T_SS_mat', matrix with dimension
len_t by sz\(\times\)sz.
Input pos should be the position matrix with dimension
M\(\times\)len_t. See bm_particle_intensity,
ou_particle_intensity, fbm_particle_intensity,
fbm_ou_particle_intensity.
Gu, M., He, Y., Liu, X., & Luo, Y. (2023). Ab initio uncertainty quantification in scattering analysis of microscopy. arXiv preprint arXiv:2309.02468.
Gu, M., Luo, Y., He, Y., Helgeson, M. E., & Valentine, M. T. (2021). Uncertainty quantification and estimation in differential dynamic microscopy. Physical Review E, 104(3), 034610.